@@ -3,9 +3,9 @@
 ;; Copyright (C) 2025 Jędrzej Kędzierski, Warsaw University of Technology, Institute of Computer Science
 
 ;; Author: Jędrzej Kędzierski <kedzierski.jedrzej@gmail.com>
-;; Package-Version: 1.0.2
-;; Package-Revision: 32b8c4077451
-;; Package-Requires: ((emacs "28.1"))
+;; Package-Version: 20251007.1441
+;; Package-Revision: b88bac22c923
+;; Package-Requires: ((emacs "27.1"))
 ;; Keywords: tools, languages, inline completions, tabby, llm
 ;; URL: https://github.com/Bastillan/tabbymacs
 ;; SPDX-License-Identifier: GPL-3.0-or-later
@@ -290,8 +290,7 @@ FMT and ARGS are like in `message'."
            (uri (tabbymacs--path-to-uri root))
            (init-params
             `(:processId ,(emacs-pid)
-                         :clientInfo (:name "emacs"
-                                            :version ,(string-clean-whitespace (emacs-version)))
+                         :clientInfo (:name "emacs" :version ,(emacs-version))
                          :rootPath ,(file-local-name root)
                          :rootUri ,uri
                          :workspaceFolders
